==> apache-fory-0.13.2-src.tar.gz: apache-fory-0.13.2-src/java/fory-core/src/test/java/org/apache/fory/resolver/SerializationContextTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.fory.resolver;

import static org.testng.Assert.*;

import org.apache.fory.config.Config;
import org.apache.fory.config.ForyBuilder;
import org.testng.annotations.Test;

public class SerializationContextTest {

  @Test
  public void testSerializationContext() {
    ForyBuilder builder = new ForyBuilder().withDeserializeNonexistentClass(false);
    builder.build(); // trigger finish
    SerializationContext context = new SerializationContext(new Config(builder));
    assertFalse(context.containsKey("A"));
    context.add("A", 1);
    assertTrue(context.containsKey("A"));
    assertEquals(context.get("A"), 1);
    context.reset();
    assertFalse(context.containsKey("A"));
  }
}

==> apache-fory-0.15.0-src.tar.gz: apache-fory-0.15.0-src/java/fory-core/src/test/java/org/apache/fory/resolver/SerializationContextTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.fory.resolver;

import static org.testng.Assert.*;

import org.apache.fory.config.Config;
import org.apache.fory.config.ForyBuilder;
import org.testng.annotations.Test;

public class SerializationContextTest {

  @Test
  public void testSerializationContext() {
    ForyBuilder builder = new ForyBuilder().withDeserializeUnknownClass(false);
    builder.build(); // trigger finish
    SerializationContext context = new SerializationContext(new Config(builder));
    assertFalse(context.containsKey("A"));
    context.add("A", 1);
    assertTrue(context.containsKey("A"));
    assertEquals(context.get("A"), 1);
    context.reset();
    assertFalse(context.containsKey("A"));
  }
}
